@@ -121,6 +121,8 @@ def Main():
     if config.has_option('Options', 'tempdir'):
         tempdirname=config['Options']['tempdir']
         logging.debug(f"Using custom temporary folder: {tempdirname}")
+        if not os.path.isdir(tempdirname):
+            os.makedirs(tempdirname)
 
     for cloudplace in config.sections():
         if cloudplace=="Options":
